local json = require("json")
local const = require("const")
local utils = require("utils")
local utils_device = require("utils_device")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DeviceManage")

if ("POST" == request_method) then
    local utils_header = require("utils_header")
    local params = utils_header.check_public_boby_data()
    local dev_list = params["DeviceList"]
    
    if dev_list == nil or type(dev_list) ~= "table" or #dev_list <= 0 then
        utils.error_exit(400, "DeviceList should be json array.")
    end

    local cmd_params = {}
    cmd_params["params"] = {}
    
    for _, dev in ipairs(dev_list) do
        pk = dev["ProductKey"]
        dn = dev["DeviceName"]

        utils.check_pk(pk)
        utils.check_dn(dn)
     
        local item = {}
        table.insert(item, pk)
        table.insert(item, dn)
        table.insert(cmd_params["params"], item)
    end

    local ok, msg_raw, err = utils.dbus_call_edge(const.dimu.wkn,
                                    const.dimu.obj,
                                    const.dimu.inf,
                                    "unauthorizeDevice",
                                    json.encode(cmd_params))
    if (ok and msg_raw) then
        local ok, msg = pcall(json.decode, msg_raw[1])
        if ok then
            if 0 == msg["code"] then
                utils.error_exit(200, json.encode(""))
            else
                local ret = {}
                local ret_error = {}
                for k, v in pairs(msg["params"]["failed_message"]) do
                    if v["code"] ~= 0 then
                        local item = {}
                        item["ProductKey"] = v["params"]["device"][1]
                        item["DeviceName"] = v["params"]["device"][2]
                        item["FaileMessage"] = v["message"]
                        table.insert(ret_error, item)
                    end
                end
                ret["code"] = 400
                ret["data"] = ret_error
                ret["message"] = ""
                ngx.say(json.encode(ret))
                ngx.exit(ngx.HTTP_OK)
            end

        end
        if (ok and 0 == msg["code"]) then
            utils.error_exit(200, json.encode(""))
        end
    else
        utils.error_exit(500, json.encode("falied to unauth"))
    end

    utils.error_exit(500, json.encode("falied to unauth"))
end

utils.error_exit(400, "unsupported request method")
