local json = require("json")
local utils = require("utils")
local const = require("const")
local pl_pretty = require("pl.pretty")
local resty_string = require("resty.string")
local pl_path = require("pl.path")
local pl_util = require("pl.utils")

local request_method = ngx.var.request_method

utils.check_login()
_, login_token = utils.check_permission("DriverManage")

local function check_param(name, value)
    
    if name == nil or type(name) ~= "string" then
        local ret = name.." must not be null"
        utils.error_exit(400, ret)
    end
end

if "POST" == request_method then
    local utils_header = require("utils_header")
    local params = utils_header.check_public_boby_data()
    local driverLanguage = params["DriverLanguage"]
    local driverName = params["DriverName"]
    local driverDesc = params["DriverDesc"]
    local driverZipPackagePath = params["DriverZipPackagePath"]
    local cur_dir = pl_path.currentdir()
    
    check_param("driverLanguage", driverLanguage)
    check_param("driverName", driverName)
    check_param("driverDesc", driverDesc)
    check_param("driverZipPackagePath", driverZipPackagePath)

    --TODO: we should not add system driver

    --FIXME: where to save these info ?
    if not pl_path.isfile(driverZipPackagePath) then 
        utils.error_exit(400, "file is not exist.")
    end

    local cmd = "killall "..driverName.." ; chmod +x "..driverZipPackagePath.." ; LD_LIBRARY_PATH="..cur_dir.."/../../lib setsid "..driverZipPackagePath.."  > /dev/null &"
    local ret, code = pl_util.execute(cmd)

    --TODO: add the binary to start script.
    local config = {}
    local driverConfig = {}
    driverConfig["DriverLanguage"] = driverLanguage
    driverConfig["DriverName"] = driverName
    driverConfig["DriverDesc"] = driverDesc
    driverConfig["DriverZipPackagePath"] = driverZipPackagePath

    config["driverConfig"] = driverConfig
    utils.set_driver_config(driverName, json.encode(config))

    if not ret then
        utils.error_exit(500, json.encode("failed to run driver: "..code))
    end 

    utils.error_exit(200, json.encode("")) 

end
utils.error_exit(400, "unsupported request method")

